@@ -6,7 +6,7 @@ use Mojo::JSON;
 use Mojo::Util 'deprecated';
 use constant DEBUG => $ENV{MOJO_OPENAPI_DEBUG} || 0;
 
-our $VERSION = '1.03';
+our $VERSION = '1.04';
 
 sub EXCEPTION { +{errors => [{message => 'Internal server error.', path => '/'}], status => 500} }
 sub NOT_FOUND { +{errors => [{message => 'Not found.',             path => '/'}], status => 404} }
@@ -177,10 +177,12 @@ sub _reply {
 
 sub _render {
   my ($renderer, $c, $output, $options) = @_;
-  my $res  = $c->stash('openapi')        or return;
+  exists $c->stash->{openapi} or return;
+
   my $self = $c->stash('openapi.object') or return;
   my $status = $c->stash('status') || 200;
-  my $v = $self->_validator;
+  my $res    = $c->stash('openapi');
+  my $v      = $self->_validator;
 
   $c->stash->{format} ||= 'json';
   delete $options->{encoding};
